@@ -1,6 +1,3 @@
-from milkman_py.hello import sayhello
-from milkman_py.hello import empty_bytes
-from milkman_py.hello import EMPTY_BYTES
 from milkman_py.main import (
     univ2_expected_out_data,
     univ3_expected_out_data,
